summaryrefslogtreecommitdiff
path: root/lib/dpif-provider.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/dpif-provider.h')
-rw-r--r--lib/dpif-provider.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/lib/dpif-provider.h b/lib/dpif-provider.h
index 62b3598ac..0d2075bf4 100644
--- a/lib/dpif-provider.h
+++ b/lib/dpif-provider.h
@@ -284,9 +284,10 @@ struct dpif_class {
* If 'terse' is true, then only UID and statistics will
* be returned in the dump. Otherwise, all fields will be returned.
*
* If 'type' isn't null, dumps only the flows of the given type. */
struct dpif_flow_dump *(*flow_dump_create)(const struct dpif *dpif,
- bool terse, char *type);
+ bool terse,
+ struct dpif_flow_dump_types *types);
int (*flow_dump_destroy)(struct dpif_flow_dump *dump);
struct dpif_flow_dump_thread *(*flow_dump_thread_create)(
@@ -284,9 +284,10 @@ struct dpif_class {
* be returned in the dump. Otherwise, all fields will be returned.
*
- * If 'type' isn't null, dumps only the flows of the given type. */
+ * If 'types' isn't null, dumps only the flows of the passed types. */
struct dpif_flow_dump *(*flow_dump_create)(const struct dpif *dpif,